Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(214)

Unified Diff: mojo/shell/static_application_loader.h

Issue 1675083002: Rename ApplicationDelegate to ShellClient (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@delegate
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mojo/shell/standalone/test/pingable_app.cc ('k') | mojo/shell/static_application_loader.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mojo/shell/static_application_loader.h
diff --git a/mojo/shell/static_application_loader.h b/mojo/shell/static_application_loader.h
index 9cb5cae93ed3571e2118a51c310a42054eb57a72..38b4a87448a522c65777dc3bce13b70958dc6807 100644
--- a/mojo/shell/static_application_loader.h
+++ b/mojo/shell/static_application_loader.h
@@ -17,20 +17,20 @@ class SimpleThread;
}
namespace mojo {
-class ApplicationDelegate;
+class ShellClient;
}
namespace mojo {
namespace shell {
// An ApplicationLoader which loads a single type of app from a given
// ApplicationDelegate factory. A Load() request is fulfilled by creating an
// instance of the app on a new thread. Only one instance of the app will run at
// a time. Any Load requests received while the app is running will be dropped.
class StaticApplicationLoader : public mojo::shell::ApplicationLoader {
public:
using ApplicationFactory =
- base::Callback<scoped_ptr<mojo::ApplicationDelegate>()>;
+ base::Callback<scoped_ptr<mojo::ShellClient>()>;
// Constructs a static loader for |factory|.
explicit StaticApplicationLoader(const ApplicationFactory& factory);
« no previous file with comments | « mojo/shell/standalone/test/pingable_app.cc ('k') | mojo/shell/static_application_loader.cc » ('j') | no next file with comments »
@@ -17,20 +17,20 @@ class SimpleThread;
namespace shell {
// An ApplicationLoader which loads a single type of app from a given
-// ApplicationDelegate factory. A Load() request is fulfilled by creating an
+// mojo::ShellClient factory. A Load() request is fulfilled by creating an
// instance of the app on a new thread. Only one instance of the app will run at
// a time. Any Load requests received while the app is running will be dropped.

Powered by Google App Engine
This is Rietveld 408576698